GeneratorWrapper class

Constructors

GeneratorWrapper(String xmlString, String inPath, String outPath)

Properties

hashCode → int
The hash code for this object.
no setterinherited
inPath → String
final
outPath → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
xmlString → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
process() → String
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited